#!/bin/zsh

CURRENT=$(git branch | grep \* | cut -d ' ' -f2)
if [ "$CURRENT" != "main" ]; then
  echo "Not on main branch"
  exit 1
fi

### Setup OpenSSL
if [ "$(uname)" = "Darwin" ]; then
  echo "macOS"
  echo "Trying to import openssl"
  OPENSSL_PATH=/usr/local/opt/openssl@1.1/lib
  if test -d "$OPENSSL_PATH"; then
    export DYLD_LIBRARY_PATH=$OPENSSL_PATH
  else
    echo "OpenSSL not found"
    exit 100
  fi
elif [ "$(uname)" = "Linux" ]; then
  echo "Linux"
else
  echo "Unknown"
fi

### Running build script
if [ -z "$1" ]; then
  echo "Usage: $0 <version> e.g. 0.8.0-beta.1"
  exit 1
fi

FILE_VERSION=$($1 | sed -r 's|^(([0-9]+).([0-9]+).([0-9]+))(.*)$|\1|')

sed -i "" -e "s|<AssemblyVersion>.*</AssemblyVersion>|<AssemblyVersion>$FILE_VERSION</AssemblyVersion>|" FitConnect/FitConnect.csproj
sed -i "" -e "s|<FileVersion>.*</FileVersion>|<FileVersion>$FILE_VERSION</FileVersion>|" FitConnect/FitConnect.csproj
sed -i "" -e "s|<PackageVersion>.*</PackageVersion>|<PackageVersion>$1</PackageVersion>|" FitConnect/FitConnect.csproj

dotnet clean

#if ! dotnet test -c Release; then
#  echo "Test failed"
#  exit 1
#fi

if ! dotnet build FitConnect -c Release; then
  echo "Build failed"
  exit 1
fi

if ! dotnet pack -c Release; then
  echo "Pack failed"
  exit 1
fi

cp "FitConnect/bin/Release/FitConnect.$1.nupkg" .



exit 0

git tag V$1
git push --tags
dotnet nuget push "FitConnect.$1.nupkg" -k $(cat nuget_api.txt) -s https://api.nuget.org/v3/index.json


# Here you can do the release things...
